Finite Differences
==================

This package implements the finite differences kernel of the code.

Cross Sections Operators
------------------------

.. automodule:: dorban.finite_differences.fd_cross_sections_operators
   :members:
   :no-undoc-members:
   :show-inheritance:

Diffusion Operator
------------------

.. automodule:: dorban.finite_differences.diffusion_operator
   :members:
   :no-undoc-members:
   :show-inheritance:

Current Calculator
------------------

.. inheritance-diagram::
   dorban.current_calculator.CurrentCalculator
   dorban.finite_differences.finite_difference_current_calculator.CurrentCalculatorFD
   dorban.finite_differences.finite_difference_current_calculator.DiscontinuityCurrentCalculator
   dorban.finite_differences.finite_difference_current_calculator.DirectionalCurrentCalculator
   :parts: 1
   :top-classes: dorban.current_calculator.CurrentCalculator

.. automodule:: dorban.finite_differences.finite_difference_current_calculator
   :members:
   :no-undoc-members:
   :show-inheritance:

Solve Finite Differences
------------------------

.. automodule:: dorban.finite_differences.solve_finite_difference
   :members:
   :no-undoc-members:
   :show-inheritance:
